@@ -397,3 +397,22 @@ def get_token(project_id: str, secret_id: str, version_id=None):
     return token
 
 
+def date_transform(input: pd.core.frame.DataFrame)->pd.core.frame.DataFrame:
+    """
+    Transforma a data em diversos formatos 
+    Args:
+        input (pd.core.frame.DataFrame): DataFrame com a data a ser transformada
+    Returns:
+        output (pd.core.frame.DataFrame): DataFrame com a data transformada
+
+    """
+    input['month'] = input['date'].dt.month
+    input['year'] = input['date'].dt.year
+    input['day'] = input['date'].dt.day
+    input['weeknumber'] = input['date'].dt.isocalendar().week ##primeira semana que contém uma quinta-feira##
+    input['weekday'] = input['date'].dt.dayofweek## começando na segunda##
+    input['monthofyear'] = pd.to_datetime(input['date']).dt.to_period('M').astype(str,errors='ignore')
+
+    input['timestamp_transf'] = pytz.timezone('America/Sao_Paulo').localize(datetime.now()).strftime("%Y-%m-%d %H:%M:%S")
+
+    return input
\ No newline at end of file
